/*
 * Copyright 2008, Haiku.
 * Distributed under the terms of the MIT License.
 *
 * Authors:
 *		Philippe Saint-Pierre < stpere@gmail.com >
 */


#include "CapsLockFilter.h"

#include <Application.h>
#include <OS.h>
#include <support/Beep.h>
#include <interface/Alert.h>

#include <Debug.h>

#include <new>

#define CALLED() SERIAL_PRINT(("%s\n", __PRETTY_FUNCTION__))

extern "C" _EXPORT BInputServerFilter* instantiate_input_filter();

/** required C func to build the IS Filter */


BInputServerFilter*
instantiate_input_filter()
{
	return new (std::nothrow) CapsLockFilter();
}


//	#pragma mark -


CapsLockFilter::CapsLockFilter(): _shiftPressed(false)
{
}


CapsLockFilter::~CapsLockFilter()
{
}


filter_result
CapsLockFilter::Filter(BMessage *message, BList *outList)
{
	switch (message->what) {
		case B_KEY_UP:
		{
			int32 key;
			if (message->FindInt32("key", &key) == B_OK && key == 0x4b)
				_shiftPressed = false;
		}
		break;
		case B_KEY_DOWN:
		{
			int32 key;
			if (message->FindInt32("key", &key) == B_OK && key == 0x4b)
				_shiftPressed = true;
		}
		break;
		case B_MODIFIERS_CHANGED:
		{
			int32 modifiers;
			if (!_shiftPressed && message->FindInt32("modifiers", &modifiers) == B_OK && (modifiers & B_CAPS_LOCK ) ) {
				(new BAlert("Hey", "capslock is disabled.\n", "ok"))->Go(NULL);
			}
			return B_SKIP_MESSAGE;
			// I return always B_SKIP_MESSAGE only to confirm my boolean formula isn't in cause..
		}
		break;
	}

	return B_DISPATCH_MESSAGE;
}

